Pažymėjimai | OiRA
Description: Priklausomai nuo nacionalinio OiRA partnerio ir (ar) priemonės kūrėjo taikomo metodo, gali būti suteikiama galimybė gauti jūsų rizikos vertinimo pažymėjimą. Dėl išsamesnės informacijos apie tokių pažymėjimų privalumus kreipkitės į savo nacionalinį OiRA partnerį.

Temos

# Pažymėjimai

Priklausomai nuo nacionalinio OiRA partnerio ir (ar) priemonės kūrėjo taikomo metodo, gali būti suteikiama galimybė gauti jūsų rizikos vertinimo pažymėjimą. Dėl išsamesnės informacijos apie tokių pažymėjimų privalumus kreipkitės į savo nacionalinį OiRA partnerį.

Kaip gauti pažymėjimą

## Atlikite visą išsamų rizikos vertinimą

Jums atliekant rizikos vertinimą, OiRA registruoja jūsų daromą pažangą. Jums įvertinus tam tikrą rizikos veiksnių skaičių, priemonėje atsiranda pranešimas, kad užbaigus visą išsamų rizikos vertinimą, galima gauti pažymėjimą. Kiekvienas nacionalinis OiRA partneris ir (ar) priemonės kūrėjas nustato ribą (procentais), kuri turi būti pasiekta, kad rizikos vertinimas būtų laikomas „išsamiu“. Pažymėjimą galima rasti ekrano kairėje esančiame meniu spustelėjus mygtuką „Būsena“.

Būsenos puslapis rodo, kad galima gauti pažymėjimą.

## Peržiūrėti ir paskelbti pažymėjimą

Spustelėjus mygtuką „Rodyti pažymėjimą“, bus paprašyta įrašyti įmonės, kuri turėtų būti nurodyta pažymėjime, pavadinimą. Priklausomai nuo atitinkamų šaliai taikomų nustatymų, jūsų gali būti paprašyta įrašyti daugiau duomenų, kurie turi būti pateikti pažymėjime.

Įveskite informaciją, kuri turi būti nurodyta pažymėjime.

Jei pažymėsite langelį „Paskelbti viešai“, atsiras unikali nuoroda (URL) į jūsų pažymėjimą. Nukopijuokite šią nuorodą ir pasidalykite ja su atitinkamais asmenimis kaip įrodymu, kad atlikote rizikos vertinimą.

Pastaba: Viešai skelbiami tik šiame puslapyje pateikti duomenys. Šios nuorodos nėra OiRA interneto svetainės meniu - ji skirta tik jums. Tačiau teoriškai visi naršydami internete gali matyti jūsų suformuotą pažymėjimą.

Pažymėjime nurodoma tik tai, kad pasitelkdami rizikos vertinimo priemonę jūs ėmėtės veiksmų tam tikriems rizikos veiksniams suvaldyti, tačiau kita informacija nepateikiama. Konkrečius atsakymus, pateiktus vertinant riziką su OiRA priemone, matote tik jūs ir niekas kitas.

Scroll to top Load toolbar…
Back

## 5-certificates.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More